devices

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 8, 2022 License: BSD-3-Clause Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client for devices API

func (*Client) GetDevices

func (a *Client) GetDevices(params *GetDevicesParams, opts ...ClientOption) (*GetDevicesOK, error)

GetDevices lists of all devices in u n m s

func (*Client) GetDevicesIDStatistics added in v0.2.0

func (a *Client) GetDevicesIDStatistics(params *GetDevicesIDStatisticsParams, opts ...ClientOption) (*GetDevicesIDStatisticsOK, error)

GetDevicesIDStatistics returns device statistics

func (*Client) SetTransport

func (a *Client) SetTransport(transport runtime.ClientTransport)

SetTransport changes the transport on the client

type ClientOption

type ClientOption func(*runtime.ClientOperation)

ClientOption is the option for Client methods

type ClientService

type ClientService interface {
	GetDevices(params *GetDevicesParams, opts ...ClientOption) (*GetDevicesOK, error)

	GetDevicesIDStatistics(params *GetDevicesIDStatisticsParams, opts ...ClientOption) (*GetDevicesIDStatisticsOK, error)

	SetTransport(transport runtime.ClientTransport)
}

ClientService is the interface for Client methods

func New

func New(transport runtime.ClientTransport, formats strfmt.Registry) ClientService

New creates a new devices API client.

type GetDevicesBadRequest

type GetDevicesBadRequest struct {
	Payload *models.Error
}

GetDevicesBadRequest describes a response with status code 400, with default header values.

Bad Request

func NewGetDevicesBadRequest

func NewGetDevicesBadRequest() *GetDevicesBadRequest

NewGetDevicesBadRequest creates a GetDevicesBadRequest with default headers values

func (*GetDevicesBadRequest) Error

func (o *GetDevicesBadRequest) Error() string

func (*GetDevicesBadRequest) GetPayload

func (o *GetDevicesBadRequest) GetPayload() *models.Error

func (*GetDevicesBadRequest) IsClientError added in v0.2.0

func (o *GetDevicesBadRequest) IsClientError() bool

IsClientError returns true when this get devices bad request response has a 4xx status code

func (*GetDevicesBadRequest) IsCode added in v0.2.0

func (o *GetDevicesBadRequest) IsCode(code int) bool

IsCode returns true when this get devices bad request response a status code equal to that given

func (*GetDevicesBadRequest) IsRedirect added in v0.2.0

func (o *GetDevicesBadRequest) IsRedirect() bool

IsRedirect returns true when this get devices bad request response has a 3xx status code

func (*GetDevicesBadRequest) IsServerError added in v0.2.0

func (o *GetDevicesBadRequest) IsServerError() bool

IsServerError returns true when this get devices bad request response has a 5xx status code

func (*GetDevicesBadRequest) IsSuccess added in v0.2.0

func (o *GetDevicesBadRequest) IsSuccess() bool

IsSuccess returns true when this get devices bad request response has a 2xx status code

func (*GetDevicesBadRequest) String added in v0.2.0

func (o *GetDevicesBadRequest) String() string

type GetDevicesForbidden

type GetDevicesForbidden struct {
	Payload *models.Error
}

GetDevicesForbidden describes a response with status code 403, with default header values.

Forbidden

func NewGetDevicesForbidden

func NewGetDevicesForbidden() *GetDevicesForbidden

NewGetDevicesForbidden creates a GetDevicesForbidden with default headers values

func (*GetDevicesForbidden) Error

func (o *GetDevicesForbidden) Error() string

func (*GetDevicesForbidden) GetPayload

func (o *GetDevicesForbidden) GetPayload() *models.Error

func (*GetDevicesForbidden) IsClientError added in v0.2.0

func (o *GetDevicesForbidden) IsClientError() bool

IsClientError returns true when this get devices forbidden response has a 4xx status code

func (*GetDevicesForbidden) IsCode added in v0.2.0

func (o *GetDevicesForbidden) IsCode(code int) bool

IsCode returns true when this get devices forbidden response a status code equal to that given

func (*GetDevicesForbidden) IsRedirect added in v0.2.0

func (o *GetDevicesForbidden) IsRedirect() bool

IsRedirect returns true when this get devices forbidden response has a 3xx status code

func (*GetDevicesForbidden) IsServerError added in v0.2.0

func (o *GetDevicesForbidden) IsServerError() bool

IsServerError returns true when this get devices forbidden response has a 5xx status code

func (*GetDevicesForbidden) IsSuccess added in v0.2.0

func (o *GetDevicesForbidden) IsSuccess() bool

IsSuccess returns true when this get devices forbidden response has a 2xx status code

func (*GetDevicesForbidden) String added in v0.2.0

func (o *GetDevicesForbidden) String() string

type GetDevicesIDStatisticsBadRequest added in v0.2.0

type GetDevicesIDStatisticsBadRequest struct {
	Payload *models.Error
}

GetDevicesIDStatisticsBadRequest describes a response with status code 400, with default header values.

Bad Request

func NewGetDevicesIDStatisticsBadRequest added in v0.2.0

func NewGetDevicesIDStatisticsBadRequest() *GetDevicesIDStatisticsBadRequest

NewGetDevicesIDStatisticsBadRequest creates a GetDevicesIDStatisticsBadRequest with default headers values

func (*GetDevicesIDStatisticsBadRequest) Error added in v0.2.0

func (*GetDevicesIDStatisticsBadRequest) GetPayload added in v0.2.0

func (*GetDevicesIDStatisticsBadRequest) IsClientError added in v0.2.0

func (o *GetDevicesIDStatisticsBadRequest) IsClientError() bool

IsClientError returns true when this get devices Id statistics bad request response has a 4xx status code

func (*GetDevicesIDStatisticsBadRequest) IsCode added in v0.2.0

func (o *GetDevicesIDStatisticsBadRequest) IsCode(code int) bool

IsCode returns true when this get devices Id statistics bad request response a status code equal to that given

func (*GetDevicesIDStatisticsBadRequest) IsRedirect added in v0.2.0

func (o *GetDevicesIDStatisticsBadRequest) IsRedirect() bool

IsRedirect returns true when this get devices Id statistics bad request response has a 3xx status code

func (*GetDevicesIDStatisticsBadRequest) IsServerError added in v0.2.0

func (o *GetDevicesIDStatisticsBadRequest) IsServerError() bool

IsServerError returns true when this get devices Id statistics bad request response has a 5xx status code

func (*GetDevicesIDStatisticsBadRequest) IsSuccess added in v0.2.0

func (o *GetDevicesIDStatisticsBadRequest) IsSuccess() bool

IsSuccess returns true when this get devices Id statistics bad request response has a 2xx status code

func (*GetDevicesIDStatisticsBadRequest) String added in v0.2.0

type GetDevicesIDStatisticsForbidden added in v0.2.0

type GetDevicesIDStatisticsForbidden struct {
	Payload *models.Error
}

GetDevicesIDStatisticsForbidden describes a response with status code 403, with default header values.

Forbidden

func NewGetDevicesIDStatisticsForbidden added in v0.2.0

func NewGetDevicesIDStatisticsForbidden() *GetDevicesIDStatisticsForbidden

NewGetDevicesIDStatisticsForbidden creates a GetDevicesIDStatisticsForbidden with default headers values

func (*GetDevicesIDStatisticsForbidden) Error added in v0.2.0

func (*GetDevicesIDStatisticsForbidden) GetPayload added in v0.2.0

func (o *GetDevicesIDStatisticsForbidden) GetPayload() *models.Error

func (*GetDevicesIDStatisticsForbidden) IsClientError added in v0.2.0

func (o *GetDevicesIDStatisticsForbidden) IsClientError() bool

IsClientError returns true when this get devices Id statistics forbidden response has a 4xx status code

func (*GetDevicesIDStatisticsForbidden) IsCode added in v0.2.0

func (o *GetDevicesIDStatisticsForbidden) IsCode(code int) bool

IsCode returns true when this get devices Id statistics forbidden response a status code equal to that given

func (*GetDevicesIDStatisticsForbidden) IsRedirect added in v0.2.0

func (o *GetDevicesIDStatisticsForbidden) IsRedirect() bool

IsRedirect returns true when this get devices Id statistics forbidden response has a 3xx status code

func (*GetDevicesIDStatisticsForbidden) IsServerError added in v0.2.0

func (o *GetDevicesIDStatisticsForbidden) IsServerError() bool

IsServerError returns true when this get devices Id statistics forbidden response has a 5xx status code

func (*GetDevicesIDStatisticsForbidden) IsSuccess added in v0.2.0

func (o *GetDevicesIDStatisticsForbidden) IsSuccess() bool

IsSuccess returns true when this get devices Id statistics forbidden response has a 2xx status code

func (*GetDevicesIDStatisticsForbidden) String added in v0.2.0

type GetDevicesIDStatisticsInternalServerError added in v0.2.0

type GetDevicesIDStatisticsInternalServerError struct {
	Payload *models.Error
}

GetDevicesIDStatisticsInternalServerError describes a response with status code 500, with default header values.

Internal Server Error

func NewGetDevicesIDStatisticsInternalServerError added in v0.2.0

func NewGetDevicesIDStatisticsInternalServerError() *GetDevicesIDStatisticsInternalServerError

NewGetDevicesIDStatisticsInternalServerError creates a GetDevicesIDStatisticsInternalServerError with default headers values

func (*GetDevicesIDStatisticsInternalServerError) Error added in v0.2.0

func (*GetDevicesIDStatisticsInternalServerError) GetPayload added in v0.2.0

func (*GetDevicesIDStatisticsInternalServerError) IsClientError added in v0.2.0

IsClientError returns true when this get devices Id statistics internal server error response has a 4xx status code

func (*GetDevicesIDStatisticsInternalServerError) IsCode added in v0.2.0

IsCode returns true when this get devices Id statistics internal server error response a status code equal to that given

func (*GetDevicesIDStatisticsInternalServerError) IsRedirect added in v0.2.0

IsRedirect returns true when this get devices Id statistics internal server error response has a 3xx status code

func (*GetDevicesIDStatisticsInternalServerError) IsServerError added in v0.2.0

IsServerError returns true when this get devices Id statistics internal server error response has a 5xx status code

func (*GetDevicesIDStatisticsInternalServerError) IsSuccess added in v0.2.0

IsSuccess returns true when this get devices Id statistics internal server error response has a 2xx status code

func (*GetDevicesIDStatisticsInternalServerError) String added in v0.2.0

type GetDevicesIDStatisticsNotFound added in v0.2.0

type GetDevicesIDStatisticsNotFound struct {
	Payload *models.Error
}

GetDevicesIDStatisticsNotFound describes a response with status code 404, with default header values.

Not Found

func NewGetDevicesIDStatisticsNotFound added in v0.2.0

func NewGetDevicesIDStatisticsNotFound() *GetDevicesIDStatisticsNotFound

NewGetDevicesIDStatisticsNotFound creates a GetDevicesIDStatisticsNotFound with default headers values

func (*GetDevicesIDStatisticsNotFound) Error added in v0.2.0

func (*GetDevicesIDStatisticsNotFound) GetPayload added in v0.2.0

func (o *GetDevicesIDStatisticsNotFound) GetPayload() *models.Error

func (*GetDevicesIDStatisticsNotFound) IsClientError added in v0.2.0

func (o *GetDevicesIDStatisticsNotFound) IsClientError() bool

IsClientError returns true when this get devices Id statistics not found response has a 4xx status code

func (*GetDevicesIDStatisticsNotFound) IsCode added in v0.2.0

func (o *GetDevicesIDStatisticsNotFound) IsCode(code int) bool

IsCode returns true when this get devices Id statistics not found response a status code equal to that given

func (*GetDevicesIDStatisticsNotFound) IsRedirect added in v0.2.0

func (o *GetDevicesIDStatisticsNotFound) IsRedirect() bool

IsRedirect returns true when this get devices Id statistics not found response has a 3xx status code

func (*GetDevicesIDStatisticsNotFound) IsServerError added in v0.2.0

func (o *GetDevicesIDStatisticsNotFound) IsServerError() bool

IsServerError returns true when this get devices Id statistics not found response has a 5xx status code

func (*GetDevicesIDStatisticsNotFound) IsSuccess added in v0.2.0

func (o *GetDevicesIDStatisticsNotFound) IsSuccess() bool

IsSuccess returns true when this get devices Id statistics not found response has a 2xx status code

func (*GetDevicesIDStatisticsNotFound) String added in v0.2.0

type GetDevicesIDStatisticsOK added in v0.2.0

type GetDevicesIDStatisticsOK struct {
	Payload *models.DeviceStatistics
}

GetDevicesIDStatisticsOK describes a response with status code 200, with default header values.

Successful

func NewGetDevicesIDStatisticsOK added in v0.2.0

func NewGetDevicesIDStatisticsOK() *GetDevicesIDStatisticsOK

NewGetDevicesIDStatisticsOK creates a GetDevicesIDStatisticsOK with default headers values

func (*GetDevicesIDStatisticsOK) Error added in v0.2.0

func (o *GetDevicesIDStatisticsOK) Error() string

func (*GetDevicesIDStatisticsOK) GetPayload added in v0.2.0

func (*GetDevicesIDStatisticsOK) IsClientError added in v0.2.0

func (o *GetDevicesIDStatisticsOK) IsClientError() bool

IsClientError returns true when this get devices Id statistics o k response has a 4xx status code

func (*GetDevicesIDStatisticsOK) IsCode added in v0.2.0

func (o *GetDevicesIDStatisticsOK) IsCode(code int) bool

IsCode returns true when this get devices Id statistics o k response a status code equal to that given

func (*GetDevicesIDStatisticsOK) IsRedirect added in v0.2.0

func (o *GetDevicesIDStatisticsOK) IsRedirect() bool

IsRedirect returns true when this get devices Id statistics o k response has a 3xx status code

func (*GetDevicesIDStatisticsOK) IsServerError added in v0.2.0

func (o *GetDevicesIDStatisticsOK) IsServerError() bool

IsServerError returns true when this get devices Id statistics o k response has a 5xx status code

func (*GetDevicesIDStatisticsOK) IsSuccess added in v0.2.0

func (o *GetDevicesIDStatisticsOK) IsSuccess() bool

IsSuccess returns true when this get devices Id statistics o k response has a 2xx status code

func (*GetDevicesIDStatisticsOK) String added in v0.2.0

func (o *GetDevicesIDStatisticsOK) String() string

type GetDevicesIDStatisticsParams added in v0.2.0

type GetDevicesIDStatisticsParams struct {

	// ID.
	ID string

	/* Interval.

	   Interval
	*/
	Interval string

	// Period.
	Period string

	// Start.
	Start string

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

GetDevicesIDStatisticsParams contains all the parameters to send to the API endpoint

for the get devices Id statistics operation.

Typically these are written to a http.Request.

func NewGetDevicesIDStatisticsParams added in v0.2.0

func NewGetDevicesIDStatisticsParams() *GetDevicesIDStatisticsParams

NewGetDevicesIDStatisticsParams creates a new GetDevicesIDStatisticsParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewGetDevicesIDStatisticsParamsWithContext added in v0.2.0

func NewGetDevicesIDStatisticsParamsWithContext(ctx context.Context) *GetDevicesIDStatisticsParams

NewGetDevicesIDStatisticsParamsWithContext creates a new GetDevicesIDStatisticsParams object with the ability to set a context for a request.

func NewGetDevicesIDStatisticsParamsWithHTTPClient added in v0.2.0

func NewGetDevicesIDStatisticsParamsWithHTTPClient(client *http.Client) *GetDevicesIDStatisticsParams

NewGetDevicesIDStatisticsParamsWithHTTPClient creates a new GetDevicesIDStatisticsParams object with the ability to set a custom HTTPClient for a request.

func NewGetDevicesIDStatisticsParamsWithTimeout added in v0.2.0

func NewGetDevicesIDStatisticsParamsWithTimeout(timeout time.Duration) *GetDevicesIDStatisticsParams

NewGetDevicesIDStatisticsParamsWithTimeout creates a new GetDevicesIDStatisticsParams object with the ability to set a timeout on a request.

func (*GetDevicesIDStatisticsParams) SetContext added in v0.2.0

func (o *GetDevicesIDStatisticsParams) SetContext(ctx context.Context)

SetContext adds the context to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) SetDefaults added in v0.2.0

func (o *GetDevicesIDStatisticsParams) SetDefaults()

SetDefaults hydrates default values in the get devices Id statistics params (not the query body).

All values with no default are reset to their zero value.

func (*GetDevicesIDStatisticsParams) SetHTTPClient added in v0.2.0

func (o *GetDevicesIDStatisticsParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) SetID added in v0.2.0

func (o *GetDevicesIDStatisticsParams) SetID(id string)

SetID adds the id to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) SetInterval added in v0.2.0

func (o *GetDevicesIDStatisticsParams) SetInterval(interval string)

SetInterval adds the interval to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) SetPeriod added in v0.2.0

func (o *GetDevicesIDStatisticsParams) SetPeriod(period string)

SetPeriod adds the period to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) SetStart added in v0.2.0

func (o *GetDevicesIDStatisticsParams) SetStart(start string)

SetStart adds the start to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) SetTimeout added in v0.2.0

func (o *GetDevicesIDStatisticsParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) WithContext added in v0.2.0

WithContext adds the context to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) WithDefaults added in v0.2.0

WithDefaults hydrates default values in the get devices Id statistics params (not the query body).

All values with no default are reset to their zero value.

func (*GetDevicesIDStatisticsParams) WithHTTPClient added in v0.2.0

WithHTTPClient adds the HTTPClient to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) WithID added in v0.2.0

WithID adds the id to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) WithInterval added in v0.2.0

WithInterval adds the interval to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) WithPeriod added in v0.2.0

WithPeriod adds the period to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) WithStart added in v0.2.0

WithStart adds the start to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) WithTimeout added in v0.2.0

WithTimeout adds the timeout to the get devices Id statistics params

func (*GetDevicesIDStatisticsParams) WriteToRequest added in v0.2.0

WriteToRequest writes these params to a swagger request

type GetDevicesIDStatisticsReader added in v0.2.0

type GetDevicesIDStatisticsReader struct {
	// contains filtered or unexported fields
}

GetDevicesIDStatisticsReader is a Reader for the GetDevicesIDStatistics structure.

func (*GetDevicesIDStatisticsReader) ReadResponse added in v0.2.0

func (o *GetDevicesIDStatisticsReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type GetDevicesIDStatisticsUnauthorized added in v0.2.0

type GetDevicesIDStatisticsUnauthorized struct {
	Payload *models.Error
}

GetDevicesIDStatisticsUnauthorized describes a response with status code 401, with default header values.

Unauthorized

func NewGetDevicesIDStatisticsUnauthorized added in v0.2.0

func NewGetDevicesIDStatisticsUnauthorized() *GetDevicesIDStatisticsUnauthorized

NewGetDevicesIDStatisticsUnauthorized creates a GetDevicesIDStatisticsUnauthorized with default headers values

func (*GetDevicesIDStatisticsUnauthorized) Error added in v0.2.0

func (*GetDevicesIDStatisticsUnauthorized) GetPayload added in v0.2.0

func (*GetDevicesIDStatisticsUnauthorized) IsClientError added in v0.2.0

func (o *GetDevicesIDStatisticsUnauthorized) IsClientError() bool

IsClientError returns true when this get devices Id statistics unauthorized response has a 4xx status code

func (*GetDevicesIDStatisticsUnauthorized) IsCode added in v0.2.0

IsCode returns true when this get devices Id statistics unauthorized response a status code equal to that given

func (*GetDevicesIDStatisticsUnauthorized) IsRedirect added in v0.2.0

func (o *GetDevicesIDStatisticsUnauthorized) IsRedirect() bool

IsRedirect returns true when this get devices Id statistics unauthorized response has a 3xx status code

func (*GetDevicesIDStatisticsUnauthorized) IsServerError added in v0.2.0

func (o *GetDevicesIDStatisticsUnauthorized) IsServerError() bool

IsServerError returns true when this get devices Id statistics unauthorized response has a 5xx status code

func (*GetDevicesIDStatisticsUnauthorized) IsSuccess added in v0.2.0

IsSuccess returns true when this get devices Id statistics unauthorized response has a 2xx status code

func (*GetDevicesIDStatisticsUnauthorized) String added in v0.2.0

type GetDevicesInternalServerError

type GetDevicesInternalServerError struct {
	Payload *models.Error
}

GetDevicesInternalServerError describes a response with status code 500, with default header values.

Internal Server Error

func NewGetDevicesInternalServerError

func NewGetDevicesInternalServerError() *GetDevicesInternalServerError

NewGetDevicesInternalServerError creates a GetDevicesInternalServerError with default headers values

func (*GetDevicesInternalServerError) Error

func (*GetDevicesInternalServerError) GetPayload

func (o *GetDevicesInternalServerError) GetPayload() *models.Error

func (*GetDevicesInternalServerError) IsClientError added in v0.2.0

func (o *GetDevicesInternalServerError) IsClientError() bool

IsClientError returns true when this get devices internal server error response has a 4xx status code

func (*GetDevicesInternalServerError) IsCode added in v0.2.0

func (o *GetDevicesInternalServerError) IsCode(code int) bool

IsCode returns true when this get devices internal server error response a status code equal to that given

func (*GetDevicesInternalServerError) IsRedirect added in v0.2.0

func (o *GetDevicesInternalServerError) IsRedirect() bool

IsRedirect returns true when this get devices internal server error response has a 3xx status code

func (*GetDevicesInternalServerError) IsServerError added in v0.2.0

func (o *GetDevicesInternalServerError) IsServerError() bool

IsServerError returns true when this get devices internal server error response has a 5xx status code

func (*GetDevicesInternalServerError) IsSuccess added in v0.2.0

func (o *GetDevicesInternalServerError) IsSuccess() bool

IsSuccess returns true when this get devices internal server error response has a 2xx status code

func (*GetDevicesInternalServerError) String added in v0.2.0

type GetDevicesOK

type GetDevicesOK struct {
	Payload []*models.DeviceStatusOverview
}

GetDevicesOK describes a response with status code 200, with default header values.

Read-only overview for device list.

func NewGetDevicesOK

func NewGetDevicesOK() *GetDevicesOK

NewGetDevicesOK creates a GetDevicesOK with default headers values

func (*GetDevicesOK) Error

func (o *GetDevicesOK) Error() string

func (*GetDevicesOK) GetPayload

func (o *GetDevicesOK) GetPayload() []*models.DeviceStatusOverview

func (*GetDevicesOK) IsClientError added in v0.2.0

func (o *GetDevicesOK) IsClientError() bool

IsClientError returns true when this get devices o k response has a 4xx status code

func (*GetDevicesOK) IsCode added in v0.2.0

func (o *GetDevicesOK) IsCode(code int) bool

IsCode returns true when this get devices o k response a status code equal to that given

func (*GetDevicesOK) IsRedirect added in v0.2.0

func (o *GetDevicesOK) IsRedirect() bool

IsRedirect returns true when this get devices o k response has a 3xx status code

func (*GetDevicesOK) IsServerError added in v0.2.0

func (o *GetDevicesOK) IsServerError() bool

IsServerError returns true when this get devices o k response has a 5xx status code

func (*GetDevicesOK) IsSuccess added in v0.2.0

func (o *GetDevicesOK) IsSuccess() bool

IsSuccess returns true when this get devices o k response has a 2xx status code

func (*GetDevicesOK) String added in v0.2.0

func (o *GetDevicesOK) String() string

type GetDevicesParams

type GetDevicesParams struct {

	// Authorized.
	Authorized *bool

	// Role.
	Role []string

	// SiteID.
	SiteID *string

	// Type.
	Type []string

	// WithInterfaces.
	WithInterfaces *bool

	Context    context.Context
	HTTPClient *http.Client
	// contains filtered or unexported fields
}

GetDevicesParams contains all the parameters to send to the API endpoint

for the get devices operation.

Typically these are written to a http.Request.

func NewGetDevicesParams

func NewGetDevicesParams() *GetDevicesParams

NewGetDevicesParams creates a new GetDevicesParams object, with the default timeout for this client.

Default values are not hydrated, since defaults are normally applied by the API server side.

To enforce default values in parameter, use SetDefaults or WithDefaults.

func NewGetDevicesParamsWithContext

func NewGetDevicesParamsWithContext(ctx context.Context) *GetDevicesParams

NewGetDevicesParamsWithContext creates a new GetDevicesParams object with the ability to set a context for a request.

func NewGetDevicesParamsWithHTTPClient

func NewGetDevicesParamsWithHTTPClient(client *http.Client) *GetDevicesParams

NewGetDevicesParamsWithHTTPClient creates a new GetDevicesParams object with the ability to set a custom HTTPClient for a request.

func NewGetDevicesParamsWithTimeout

func NewGetDevicesParamsWithTimeout(timeout time.Duration) *GetDevicesParams

NewGetDevicesParamsWithTimeout creates a new GetDevicesParams object with the ability to set a timeout on a request.

func (*GetDevicesParams) SetAuthorized

func (o *GetDevicesParams) SetAuthorized(authorized *bool)

SetAuthorized adds the authorized to the get devices params

func (*GetDevicesParams) SetContext

func (o *GetDevicesParams) SetContext(ctx context.Context)

SetContext adds the context to the get devices params

func (*GetDevicesParams) SetDefaults

func (o *GetDevicesParams) SetDefaults()

SetDefaults hydrates default values in the get devices params (not the query body).

All values with no default are reset to their zero value.

func (*GetDevicesParams) SetHTTPClient

func (o *GetDevicesParams) SetHTTPClient(client *http.Client)

SetHTTPClient adds the HTTPClient to the get devices params

func (*GetDevicesParams) SetRole

func (o *GetDevicesParams) SetRole(role []string)

SetRole adds the role to the get devices params

func (*GetDevicesParams) SetSiteID

func (o *GetDevicesParams) SetSiteID(siteID *string)

SetSiteID adds the siteId to the get devices params

func (*GetDevicesParams) SetTimeout

func (o *GetDevicesParams) SetTimeout(timeout time.Duration)

SetTimeout adds the timeout to the get devices params

func (*GetDevicesParams) SetType

func (o *GetDevicesParams) SetType(typeVar []string)

SetType adds the type to the get devices params

func (*GetDevicesParams) SetWithInterfaces

func (o *GetDevicesParams) SetWithInterfaces(withInterfaces *bool)

SetWithInterfaces adds the withInterfaces to the get devices params

func (*GetDevicesParams) WithAuthorized

func (o *GetDevicesParams) WithAuthorized(authorized *bool) *GetDevicesParams

WithAuthorized adds the authorized to the get devices params

func (*GetDevicesParams) WithContext

func (o *GetDevicesParams) WithContext(ctx context.Context) *GetDevicesParams

WithContext adds the context to the get devices params

func (*GetDevicesParams) WithDefaults

func (o *GetDevicesParams) WithDefaults() *GetDevicesParams

WithDefaults hydrates default values in the get devices params (not the query body).

All values with no default are reset to their zero value.

func (*GetDevicesParams) WithHTTPClient

func (o *GetDevicesParams) WithHTTPClient(client *http.Client) *GetDevicesParams

WithHTTPClient adds the HTTPClient to the get devices params

func (*GetDevicesParams) WithRole

func (o *GetDevicesParams) WithRole(role []string) *GetDevicesParams

WithRole adds the role to the get devices params

func (*GetDevicesParams) WithSiteID

func (o *GetDevicesParams) WithSiteID(siteID *string) *GetDevicesParams

WithSiteID adds the siteID to the get devices params

func (*GetDevicesParams) WithTimeout

func (o *GetDevicesParams) WithTimeout(timeout time.Duration) *GetDevicesParams

WithTimeout adds the timeout to the get devices params

func (*GetDevicesParams) WithType

func (o *GetDevicesParams) WithType(typeVar []string) *GetDevicesParams

WithType adds the typeVar to the get devices params

func (*GetDevicesParams) WithWithInterfaces

func (o *GetDevicesParams) WithWithInterfaces(withInterfaces *bool) *GetDevicesParams

WithWithInterfaces adds the withInterfaces to the get devices params

func (*GetDevicesParams) WriteToRequest

func (o *GetDevicesParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error

WriteToRequest writes these params to a swagger request

type GetDevicesReader

type GetDevicesReader struct {
	// contains filtered or unexported fields
}

GetDevicesReader is a Reader for the GetDevices structure.

func (*GetDevicesReader) ReadResponse

func (o *GetDevicesReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)

ReadResponse reads a server response into the received o.

type GetDevicesUnauthorized

type GetDevicesUnauthorized struct {
	Payload *models.Error
}

GetDevicesUnauthorized describes a response with status code 401, with default header values.

Unauthorized

func NewGetDevicesUnauthorized

func NewGetDevicesUnauthorized() *GetDevicesUnauthorized

NewGetDevicesUnauthorized creates a GetDevicesUnauthorized with default headers values

func (*GetDevicesUnauthorized) Error

func (o *GetDevicesUnauthorized) Error() string

func (*GetDevicesUnauthorized) GetPayload

func (o *GetDevicesUnauthorized) GetPayload() *models.Error

func (*GetDevicesUnauthorized) IsClientError added in v0.2.0

func (o *GetDevicesUnauthorized) IsClientError() bool

IsClientError returns true when this get devices unauthorized response has a 4xx status code

func (*GetDevicesUnauthorized) IsCode added in v0.2.0

func (o *GetDevicesUnauthorized) IsCode(code int) bool

IsCode returns true when this get devices unauthorized response a status code equal to that given

func (*GetDevicesUnauthorized) IsRedirect added in v0.2.0

func (o *GetDevicesUnauthorized) IsRedirect() bool

IsRedirect returns true when this get devices unauthorized response has a 3xx status code

func (*GetDevicesUnauthorized) IsServerError added in v0.2.0

func (o *GetDevicesUnauthorized) IsServerError() bool

IsServerError returns true when this get devices unauthorized response has a 5xx status code

func (*GetDevicesUnauthorized) IsSuccess added in v0.2.0

func (o *GetDevicesUnauthorized) IsSuccess() bool

IsSuccess returns true when this get devices unauthorized response has a 2xx status code

func (*GetDevicesUnauthorized) String added in v0.2.0

func (o *GetDevicesUnauthorized) String() string

Jump to